@@ -141,191 +141,6 @@ def login():
         raise Exception("Batchx token not set. Please run: bx.connect()")
 
 
-from . import log_pb2
-from . import log_pb2_grpc
-class LogService:
-
-    def LogRecord(self, **kwargs):
-        return log_pb2.LogRecord(**kwargs)
-
-
-from . import picture_pb2
-from . import picture_pb2_grpc
-class PictureService:
-
-    def CompleteUpload(self, request):
-        check()
-        return make_call(picture_pb2_grpc.PictureServiceStub(channel).CompleteUpload, request)
-
-    def CropPicture(self, request):
-        check()
-        return make_call(picture_pb2_grpc.PictureServiceStub(channel).CropPicture, request)
-
-    def Upload(self, request):
-        check()
-        return make_call(picture_pb2_grpc.PictureServiceStub(channel).Upload, request)
-
-    def CompleteUploadRequest(self, **kwargs):
-        return picture_pb2.CompleteUploadRequest(**kwargs)
-
-    def CompleteUploadResponse(self, **kwargs):
-        return picture_pb2.CompleteUploadResponse(**kwargs)
-
-    def CropPictureRequest(self, **kwargs):
-        return picture_pb2.CropPictureRequest(**kwargs)
-
-    def CropPictureResponse(self, **kwargs):
-        return picture_pb2.CropPictureResponse(**kwargs)
-
-    def UploadRequest(self, **kwargs):
-        return picture_pb2.UploadRequest(**kwargs)
-
-    def UploadResponse(self, **kwargs):
-        return picture_pb2.UploadResponse(**kwargs)
-
-
-from . import admin_pb2
-from . import admin_pb2_grpc
-class AdminService:
-
-    def AddEnvironmentCredits(self, request):
-        check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).AddEnvironmentCredits, request)
-
-    def CreateMembership(self, request):
-        check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateMembership, request)
-
-    def CreateOrg(self, request):
-        check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateOrg, request)
-
-    def CreateUser(self, request):
-        check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateUser, request)
-
-    def GetGlobalProperties(self, request):
-        check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).GetGlobalProperties, request)
-
-    def SetGlobalProperty(self, request):
-        check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).SetGlobalProperty, request)
-
-    def AddEnvironmentCreditsRequest(self, **kwargs):
-        return admin_pb2.AddEnvironmentCreditsRequest(**kwargs)
-
-    def AddEnvironmentCreditsResponse(self, **kwargs):
-        return admin_pb2.AddEnvironmentCreditsResponse(**kwargs)
-
-    def Assignment(self, **kwargs):
-        return admin_pb2.Assignment(**kwargs)
-
-    def CreateMembershipRequest(self, **kwargs):
-        return admin_pb2.CreateMembershipRequest(**kwargs)
-
-    def CreateMembershipResponse(self, **kwargs):
-        return admin_pb2.CreateMembershipResponse(**kwargs)
-
-    def CreateOrgRequest(self, **kwargs):
-        return admin_pb2.CreateOrgRequest(**kwargs)
-
-    def CreateOrgResponse(self, **kwargs):
-        return admin_pb2.CreateOrgResponse(**kwargs)
-
-    def CreateUserRequest(self, **kwargs):
-        return admin_pb2.CreateUserRequest(**kwargs)
-
-    def CreateUserResponse(self, **kwargs):
-        return admin_pb2.CreateUserResponse(**kwargs)
-
-    def GetGlobalPropertiesRequest(self, **kwargs):
-        return admin_pb2.GetGlobalPropertiesRequest(**kwargs)
-
-    def GetGlobalPropertiesResponse(self, **kwargs):
-        return admin_pb2.GetGlobalPropertiesResponse(**kwargs)
-
-    def SetGlobalPropertyRequest(self, **kwargs):
-        return admin_pb2.SetGlobalPropertyRequest(**kwargs)
-
-    def SetGlobalPropertyResponse(self, **kwargs):
-        return admin_pb2.SetGlobalPropertyResponse(**kwargs)
-
-
-from . import tag_pb2
-from . import tag_pb2_grpc
-class TagService:
-
-    def CreateTag(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).CreateTag, request)
-
-    def DeleteTag(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).DeleteTag, request)
-
-    def DisableTag(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).DisableTag, request)
-
-    def GetTag(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).GetTag, request)
-
-    def ListEnvironmentTags(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).ListEnvironmentTags, request)
-
-    def UpdateTag(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).UpdateTag, request)
-
-    def CreateTagRequest(self, **kwargs):
-        return tag_pb2.CreateTagRequest(**kwargs)
-
-    def CreateTagResponse(self, **kwargs):
-        return tag_pb2.CreateTagResponse(**kwargs)
-
-    def DeleteTagRequest(self, **kwargs):
-        return tag_pb2.DeleteTagRequest(**kwargs)
-
-    def DeleteTagResponse(self, **kwargs):
-        return tag_pb2.DeleteTagResponse(**kwargs)
-
-    def DisableTagRequest(self, **kwargs):
-        return tag_pb2.DisableTagRequest(**kwargs)
-
-    def DisableTagResponse(self, **kwargs):
-        return tag_pb2.DisableTagResponse(**kwargs)
-
-    def GetTagRequest(self, **kwargs):
-        return tag_pb2.GetTagRequest(**kwargs)
-
-    def GetTagResponse(self, **kwargs):
-        return tag_pb2.GetTagResponse(**kwargs)
-
-    def ListEnvironmentTagsRequest(self, **kwargs):
-        return tag_pb2.ListEnvironmentTagsRequest(**kwargs)
-
-    def ListEnvironmentTagsResponse(self, **kwargs):
-        return tag_pb2.ListEnvironmentTagsResponse(**kwargs)
-
-    def Tag(self, **kwargs):
-        return tag_pb2.Tag(**kwargs)
-
-    def TagCoordinates(self, **kwargs):
-        return tag_pb2.TagCoordinates(**kwargs)
-
-    def TagData(self, **kwargs):
-        return tag_pb2.TagData(**kwargs)
-
-    def UpdateTagRequest(self, **kwargs):
-        return tag_pb2.UpdateTagRequest(**kwargs)
-
-    def UpdateTagResponse(self, **kwargs):
-        return tag_pb2.UpdateTagResponse(**kwargs)
-
-
 from . import job_pb2
 from . import job_pb2_grpc
 class JobService:
@@ -525,6 +340,256 @@ class JobService:
         return job_pb2.Workflow(**kwargs)
 
 
+from . import health_pb2
+from . import health_pb2_grpc
+class HealthService:
+
+    def HealthCheckRequest(self, **kwargs):
+        return health_pb2.HealthCheckRequest(**kwargs)
+
+    def HealthCheckResponse(self, **kwargs):
+        return health_pb2.HealthCheckResponse(**kwargs)
+
+
+from . import docker_pb2
+from . import docker_pb2_grpc
+class DockerService:
+
+    def DockerImageCoordinates(self, **kwargs):
+        return docker_pb2.DockerImageCoordinates(**kwargs)
+
+
+from . import profile_pb2
+from . import profile_pb2_grpc
+class ProfileService:
+
+    def Profile(self, **kwargs):
+        return profile_pb2.Profile(**kwargs)
+
+
+from . import user_pb2
+from . import user_pb2_grpc
+class UserService:
+
+    def GetUser(self, request):
+        check()
+        return make_call(user_pb2_grpc.UserServiceStub(channel).GetUser, request)
+
+    def UpdateUser(self, request):
+        check()
+        return make_call(user_pb2_grpc.UserServiceStub(channel).UpdateUser, request)
+
+    def GetUserRequest(self, **kwargs):
+        return user_pb2.GetUserRequest(**kwargs)
+
+    def GetUserResponse(self, **kwargs):
+        return user_pb2.GetUserResponse(**kwargs)
+
+    def UpdateUserRequest(self, **kwargs):
+        return user_pb2.UpdateUserRequest(**kwargs)
+
+    def UpdateUserResponse(self, **kwargs):
+        return user_pb2.UpdateUserResponse(**kwargs)
+
+
+from . import picture_pb2
+from . import picture_pb2_grpc
+class PictureService:
+
+    def CompleteUpload(self, request):
+        check()
+        return make_call(picture_pb2_grpc.PictureServiceStub(channel).CompleteUpload, request)
+
+    def CropPicture(self, request):
+        check()
+        return make_call(picture_pb2_grpc.PictureServiceStub(channel).CropPicture, request)
+
+    def Upload(self, request):
+        check()
+        return make_call(picture_pb2_grpc.PictureServiceStub(channel).Upload, request)
+
+    def CompleteUploadRequest(self, **kwargs):
+        return picture_pb2.CompleteUploadRequest(**kwargs)
+
+    def CompleteUploadResponse(self, **kwargs):
+        return picture_pb2.CompleteUploadResponse(**kwargs)
+
+    def CropPictureRequest(self, **kwargs):
+        return picture_pb2.CropPictureRequest(**kwargs)
+
+    def CropPictureResponse(self, **kwargs):
+        return picture_pb2.CropPictureResponse(**kwargs)
+
+    def UploadRequest(self, **kwargs):
+        return picture_pb2.UploadRequest(**kwargs)
+
+    def UploadResponse(self, **kwargs):
+        return picture_pb2.UploadResponse(**kwargs)
+
+
+from . import provider_pb2
+from . import provider_pb2_grpc
+class ProviderService:
+
+    def GetMetrics(self, request):
+        check()
+        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).GetMetrics, request)
+
+    def ListPayouts(self, request):
+        check()
+        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).ListPayouts, request)
+
+    def ListRevenueByCustomer(self, request):
+        check()
+        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).ListRevenueByCustomer, request)
+
+    def ListRevenueByTools(self, request):
+        check()
+        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).ListRevenueByTools, request)
+
+    def GetMetricsRequest(self, **kwargs):
+        return provider_pb2.GetMetricsRequest(**kwargs)
+
+    def GetMetricsResponse(self, **kwargs):
+        return provider_pb2.GetMetricsResponse(**kwargs)
+
+    def ListPayoutsRequest(self, **kwargs):
+        return provider_pb2.ListPayoutsRequest(**kwargs)
+
+    def ListPayoutsResponse(self, **kwargs):
+        return provider_pb2.ListPayoutsResponse(**kwargs)
+
+    def ListRevenueByCustomerRequest(self, **kwargs):
+        return provider_pb2.ListRevenueByCustomerRequest(**kwargs)
+
+    def ListRevenueByCustomerResponse(self, **kwargs):
+        return provider_pb2.ListRevenueByCustomerResponse(**kwargs)
+
+    def ListRevenueByToolsRequest(self, **kwargs):
+        return provider_pb2.ListRevenueByToolsRequest(**kwargs)
+
+    def ListRevenueByToolsResponse(self, **kwargs):
+        return provider_pb2.ListRevenueByToolsResponse(**kwargs)
+
+    def Payout(self, **kwargs):
+        return provider_pb2.Payout(**kwargs)
+
+
+from . import common_pb2
+from . import common_pb2_grpc
+class CommonService:
+
+    def IntRangeFilter(self, **kwargs):
+        return common_pb2.IntRangeFilter(**kwargs)
+
+    def LongRangeFilter(self, **kwargs):
+        return common_pb2.LongRangeFilter(**kwargs)
+
+    def Organization(self, **kwargs):
+        return common_pb2.Organization(**kwargs)
+
+    def PageInfo(self, **kwargs):
+        return common_pb2.PageInfo(**kwargs)
+
+    def Picture(self, **kwargs):
+        return common_pb2.Picture(**kwargs)
+
+    def RateLimit(self, **kwargs):
+        return common_pb2.RateLimit(**kwargs)
+
+    def Region(self, **kwargs):
+        return common_pb2.Region(**kwargs)
+
+    def Thumbnail(self, **kwargs):
+        return common_pb2.Thumbnail(**kwargs)
+
+    def User(self, **kwargs):
+        return common_pb2.User(**kwargs)
+
+
+from . import environment_pb2
+from . import environment_pb2_grpc
+class EnvironmentService:
+
+    def GetEnvironment(self, request):
+        check()
+        return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).GetEnvironment, request)
+
+    def GetEnvironmentRequest(self, **kwargs):
+        return environment_pb2.GetEnvironmentRequest(**kwargs)
+
+    def GetEnvironmentResponse(self, **kwargs):
+        return environment_pb2.GetEnvironmentResponse(**kwargs)
+
+
+from . import admin_pb2
+from . import admin_pb2_grpc
+class AdminService:
+
+    def AddEnvironmentCredits(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).AddEnvironmentCredits, request)
+
+    def CreateMembership(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateMembership, request)
+
+    def CreateOrg(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateOrg, request)
+
+    def CreateUser(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateUser, request)
+
+    def GetGlobalProperties(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).GetGlobalProperties, request)
+
+    def SetGlobalProperty(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).SetGlobalProperty, request)
+
+    def AddEnvironmentCreditsRequest(self, **kwargs):
+        return admin_pb2.AddEnvironmentCreditsRequest(**kwargs)
+
+    def AddEnvironmentCreditsResponse(self, **kwargs):
+        return admin_pb2.AddEnvironmentCreditsResponse(**kwargs)
+
+    def Assignment(self, **kwargs):
+        return admin_pb2.Assignment(**kwargs)
+
+    def CreateMembershipRequest(self, **kwargs):
+        return admin_pb2.CreateMembershipRequest(**kwargs)
+
+    def CreateMembershipResponse(self, **kwargs):
+        return admin_pb2.CreateMembershipResponse(**kwargs)
+
+    def CreateOrgRequest(self, **kwargs):
+        return admin_pb2.CreateOrgRequest(**kwargs)
+
+    def CreateOrgResponse(self, **kwargs):
+        return admin_pb2.CreateOrgResponse(**kwargs)
+
+    def CreateUserRequest(self, **kwargs):
+        return admin_pb2.CreateUserRequest(**kwargs)
+
+    def CreateUserResponse(self, **kwargs):
+        return admin_pb2.CreateUserResponse(**kwargs)
+
+    def GetGlobalPropertiesRequest(self, **kwargs):
+        return admin_pb2.GetGlobalPropertiesRequest(**kwargs)
+
+    def GetGlobalPropertiesResponse(self, **kwargs):
+        return admin_pb2.GetGlobalPropertiesResponse(**kwargs)
+
+    def SetGlobalPropertyRequest(self, **kwargs):
+        return admin_pb2.SetGlobalPropertyRequest(**kwargs)
+
+    def SetGlobalPropertyResponse(self, **kwargs):
+        return admin_pb2.SetGlobalPropertyResponse(**kwargs)
+
+
 from . import auth_pb2
 from . import auth_pb2_grpc
 class AuthService:
@@ -549,6 +614,10 @@ class AuthService:
         check()
         return make_call(auth_pb2_grpc.AuthServiceStub(channel).RevokeRefreshToken, request)
 
+    def Signup(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).Signup, request)
+
     def ConfirmForgotPasswordRequest(self, **kwargs):
         return auth_pb2.ConfirmForgotPasswordRequest(**kwargs)
 
@@ -579,6 +648,20 @@ class AuthService:
     def RevokeRefreshTokenResponse(self, **kwargs):
         return auth_pb2.RevokeRefreshTokenResponse(**kwargs)
 
+    def SignupRequest(self, **kwargs):
+        return auth_pb2.SignupRequest(**kwargs)
+
+    def SignupResponse(self, **kwargs):
+        return auth_pb2.SignupResponse(**kwargs)
+
+
+from . import log_pb2
+from . import log_pb2_grpc
+class LogService:
+
+    def LogRecord(self, **kwargs):
+        return log_pb2.LogRecord(**kwargs)
+
 
 from . import image_pb2
 from . import image_pb2_grpc
@@ -672,6 +755,24 @@ class ImageService:
         return image_pb2.TagImageResponse(**kwargs)
 
 
+from . import audit_pb2
+from . import audit_pb2_grpc
+class AuditService:
+
+    def ListEvents(self, request):
+        check()
+        return make_call(audit_pb2_grpc.AuditServiceStub(channel).ListEvents, request)
+
+    def Event(self, **kwargs):
+        return audit_pb2.Event(**kwargs)
+
+    def ListEventsRequest(self, **kwargs):
+        return audit_pb2.ListEventsRequest(**kwargs)
+
+    def ListEventsResponse(self, **kwargs):
+        return audit_pb2.ListEventsResponse(**kwargs)
+
+
 from . import filesystem_pb2
 from . import filesystem_pb2_grpc
 class FilesystemService:
@@ -828,83 +929,93 @@ class FilesystemService:
         return filesystem_pb2.UploadPresignedResponse(**kwargs)
 
 
-from . import docker_pb2
-from . import docker_pb2_grpc
-class DockerService:
+from . import token_pb2
+from . import token_pb2_grpc
+class TokenService:
 
-    def DockerImageCoordinates(self, **kwargs):
-        return docker_pb2.DockerImageCoordinates(**kwargs)
-
-
-from . import profile_pb2
-from . import profile_pb2_grpc
-class ProfileService:
-
-    def Profile(self, **kwargs):
-        return profile_pb2.Profile(**kwargs)
-
-
-from . import provider_pb2
-from . import provider_pb2_grpc
-class ProviderService:
-
-    def GetMetrics(self, request):
+    def AddToken(self, request):
         check()
-        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).GetMetrics, request)
+        return make_call(token_pb2_grpc.TokenServiceStub(channel).AddToken, request)
 
-    def ListPayouts(self, request):
+    def AddTokenRequest(self, **kwargs):
+        return token_pb2.AddTokenRequest(**kwargs)
+
+    def AddTokenResponse(self, **kwargs):
+        return token_pb2.AddTokenResponse(**kwargs)
+
+
+from . import tag_pb2
+from . import tag_pb2_grpc
+class TagService:
+
+    def CreateTag(self, request):
         check()
-        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).ListPayouts, request)
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).CreateTag, request)
 
-    def ListRevenueByCustomer(self, request):
+    def DeleteTag(self, request):
         check()
-        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).ListRevenueByCustomer, request)
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).DeleteTag, request)
 
-    def ListRevenueByTools(self, request):
+    def DisableTag(self, request):
         check()
-        return make_call(provider_pb2_grpc.ProviderServiceStub(channel).ListRevenueByTools, request)
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).DisableTag, request)
 
-    def GetMetricsRequest(self, **kwargs):
-        return provider_pb2.GetMetricsRequest(**kwargs)
-
-    def GetMetricsResponse(self, **kwargs):
-        return provider_pb2.GetMetricsResponse(**kwargs)
-
-    def ListPayoutsRequest(self, **kwargs):
-        return provider_pb2.ListPayoutsRequest(**kwargs)
-
-    def ListPayoutsResponse(self, **kwargs):
-        return provider_pb2.ListPayoutsResponse(**kwargs)
-
-    def ListRevenueByCustomerRequest(self, **kwargs):
-        return provider_pb2.ListRevenueByCustomerRequest(**kwargs)
-
-    def ListRevenueByCustomerResponse(self, **kwargs):
-        return provider_pb2.ListRevenueByCustomerResponse(**kwargs)
-
-    def ListRevenueByToolsRequest(self, **kwargs):
-        return provider_pb2.ListRevenueByToolsRequest(**kwargs)
-
-    def ListRevenueByToolsResponse(self, **kwargs):
-        return provider_pb2.ListRevenueByToolsResponse(**kwargs)
-
-    def Payout(self, **kwargs):
-        return provider_pb2.Payout(**kwargs)
-
-
-from . import environment_pb2
-from . import environment_pb2_grpc
-class EnvironmentService:
-
-    def GetEnvironment(self, request):
+    def GetTag(self, request):
         check()
-        return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).GetEnvironment, request)
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).GetTag, request)
 
-    def GetEnvironmentRequest(self, **kwargs):
-        return environment_pb2.GetEnvironmentRequest(**kwargs)
+    def ListEnvironmentTags(self, request):
+        check()
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).ListEnvironmentTags, request)
 
-    def GetEnvironmentResponse(self, **kwargs):
-        return environment_pb2.GetEnvironmentResponse(**kwargs)
+    def UpdateTag(self, request):
+        check()
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).UpdateTag, request)
+
+    def CreateTagRequest(self, **kwargs):
+        return tag_pb2.CreateTagRequest(**kwargs)
+
+    def CreateTagResponse(self, **kwargs):
+        return tag_pb2.CreateTagResponse(**kwargs)
+
+    def DeleteTagRequest(self, **kwargs):
+        return tag_pb2.DeleteTagRequest(**kwargs)
+
+    def DeleteTagResponse(self, **kwargs):
+        return tag_pb2.DeleteTagResponse(**kwargs)
+
+    def DisableTagRequest(self, **kwargs):
+        return tag_pb2.DisableTagRequest(**kwargs)
+
+    def DisableTagResponse(self, **kwargs):
+        return tag_pb2.DisableTagResponse(**kwargs)
+
+    def GetTagRequest(self, **kwargs):
+        return tag_pb2.GetTagRequest(**kwargs)
+
+    def GetTagResponse(self, **kwargs):
+        return tag_pb2.GetTagResponse(**kwargs)
+
+    def ListEnvironmentTagsRequest(self, **kwargs):
+        return tag_pb2.ListEnvironmentTagsRequest(**kwargs)
+
+    def ListEnvironmentTagsResponse(self, **kwargs):
+        return tag_pb2.ListEnvironmentTagsResponse(**kwargs)
+
+    def Tag(self, **kwargs):
+        return tag_pb2.Tag(**kwargs)
+
+    def TagCoordinates(self, **kwargs):
+        return tag_pb2.TagCoordinates(**kwargs)
+
+    def TagData(self, **kwargs):
+        return tag_pb2.TagData(**kwargs)
+
+    def UpdateTagRequest(self, **kwargs):
+        return tag_pb2.UpdateTagRequest(**kwargs)
+
+    def UpdateTagResponse(self, **kwargs):
+        return tag_pb2.UpdateTagResponse(**kwargs)
 
 
 from . import organization_pb2
@@ -931,104 +1042,3 @@ class OrganizationService:
     def UpdateOrganizationResponse(self, **kwargs):
         return organization_pb2.UpdateOrganizationResponse(**kwargs)
 
-
-from . import token_pb2
-from . import token_pb2_grpc
-class TokenService:
-
-    def AddToken(self, request):
-        check()
-        return make_call(token_pb2_grpc.TokenServiceStub(channel).AddToken, request)
-
-    def AddTokenRequest(self, **kwargs):
-        return token_pb2.AddTokenRequest(**kwargs)
-
-    def AddTokenResponse(self, **kwargs):
-        return token_pb2.AddTokenResponse(**kwargs)
-
-
-from . import common_pb2
-from . import common_pb2_grpc
-class CommonService:
-
-    def IntRangeFilter(self, **kwargs):
-        return common_pb2.IntRangeFilter(**kwargs)
-
-    def LongRangeFilter(self, **kwargs):
-        return common_pb2.LongRangeFilter(**kwargs)
-
-    def Organization(self, **kwargs):
-        return common_pb2.Organization(**kwargs)
-
-    def PageInfo(self, **kwargs):
-        return common_pb2.PageInfo(**kwargs)
-
-    def Picture(self, **kwargs):
-        return common_pb2.Picture(**kwargs)
-
-    def RateLimit(self, **kwargs):
-        return common_pb2.RateLimit(**kwargs)
-
-    def Region(self, **kwargs):
-        return common_pb2.Region(**kwargs)
-
-    def Thumbnail(self, **kwargs):
-        return common_pb2.Thumbnail(**kwargs)
-
-    def User(self, **kwargs):
-        return common_pb2.User(**kwargs)
-
-
-from . import audit_pb2
-from . import audit_pb2_grpc
-class AuditService:
-
-    def ListEvents(self, request):
-        check()
-        return make_call(audit_pb2_grpc.AuditServiceStub(channel).ListEvents, request)
-
-    def Event(self, **kwargs):
-        return audit_pb2.Event(**kwargs)
-
-    def ListEventsRequest(self, **kwargs):
-        return audit_pb2.ListEventsRequest(**kwargs)
-
-    def ListEventsResponse(self, **kwargs):
-        return audit_pb2.ListEventsResponse(**kwargs)
-
-
-from . import user_pb2
-from . import user_pb2_grpc
-class UserService:
-
-    def GetUser(self, request):
-        check()
-        return make_call(user_pb2_grpc.UserServiceStub(channel).GetUser, request)
-
-    def UpdateUser(self, request):
-        check()
-        return make_call(user_pb2_grpc.UserServiceStub(channel).UpdateUser, request)
-
-    def GetUserRequest(self, **kwargs):
-        return user_pb2.GetUserRequest(**kwargs)
-
-    def GetUserResponse(self, **kwargs):
-        return user_pb2.GetUserResponse(**kwargs)
-
-    def UpdateUserRequest(self, **kwargs):
-        return user_pb2.UpdateUserRequest(**kwargs)
-
-    def UpdateUserResponse(self, **kwargs):
-        return user_pb2.UpdateUserResponse(**kwargs)
-
-
-from . import health_pb2
-from . import health_pb2_grpc
-class HealthService:
-
-    def HealthCheckRequest(self, **kwargs):
-        return health_pb2.HealthCheckRequest(**kwargs)
-
-    def HealthCheckResponse(self, **kwargs):
-        return health_pb2.HealthCheckResponse(**kwargs)
-
